@@ -1,6 +1,5 @@
 from easy_sqlalchemy.types.guid import GUID
 from easy_sqlalchemy.types.inet import INET
-from easy_sqlalchemy.types.hstore import Hstore
 
 
-__all__ = ['GUID', 'INET', 'Hstore']
\ No newline at end of file
+__all__ = ['GUID', 'INET']
